#!/usr/bin/env perl

package SOFA;

use File::Basename;
use File::Spec;
use Cwd;

sub getConfig() {

%config = ( "RMIPORT" , 2000,
            "RMIHOST" , "localhost",
            "ORBPORT" , 2001,
            "ORBHOST" , "localhost",
            "POLICY"  , "default",
            "TRURL"   , "default",
            "RMICODEBASE" , "default",
            "TIRSTORAGE"  , "default",
            "TRDIR" , "",
            "CCNSSTORAGE",  "default",
            "NODENAME", "default",
            "SOFANODES", "default"
          );

$dirname = dirname($0);
$confname = File::Spec->catfile($dirname,"..","conf","main.conf");
open(CONF, $confname);
while (<CONF>) {
  chomp;
  s/#.*$//;
  s/^\s*//;
  s/\s*$//;
  s/\s+/ /g;
  next if (/^\s*$/ || /^$/);
  @pair = split(/\ /);
  $config{$pair[0]} = $pair[1];
}
close(CONF);

if ($config{"POLICY"} eq "default") {
  $config{"POLICY"} = File::Spec->catfile($dirname, "..", "conf", ".java.policy");
}
if ($config{"TIRSTORAGE"} eq "default") {
  $config{"TIRSTORAGE"} = File::Spec->catfile($dirname, "..", "storage");
}
if ($config{"CCNSSTORAGE"} eq "default") {
  $config{"CCNSSTORAGE"} = File::Spec->catfile($dirname, "..", "storage","ccns.dat");
}
if ($config{"SOFANODES"} eq "default") {
  $config{"SOFANODES"} = File::Spec->catfile($dirname, "..", "conf", "nodes.conf");
}

my $url = File::Spec->catfile($dirname, "..");
$url =~ s/\\/\//g;
if ($url =~ /^\// || $url =~ /^[A-Za-z]:/) {
  $url = "file://" . $url;
} else {
  my $cwd = Cwd::cwd;
  $url = "file://" . $cwd . "/" . $url;
}

$url =~ s/\/\.\//\//g;
$url =~ s/\/[^\/]+\/\.\.//g;

my $surl = $url . "/TRdir/";
$surl =~ s/^file:\/\/([^\/*])/file:\/\/\/$1/;

if ($config{"TRURL"} eq "default") {
  $config{"TRURL"} = $surl;
}
if ($config{"RMICODEBASE"} eq "default") {
  $config{"RMICODEBASE"} = $surl . "conn/";
}
if ($config{"TRDIR"} eq "default") {
  $config{"TRDIR"} = File::Spec->catfile($dirname, "..", "TRdir");
}
return %config;
}

1;
